@@ -1,3 +1,4 @@
+import os
 from dash import html, dcc, Dash, get_app
 import dash_bootstrap_components as dbc
 import visdcc
@@ -95,9 +96,6 @@ def preview_box():
     ], style={'margin-bottom':'20px'})
 
 
-def _get_cwd() -> str:
-    return str(Path(getattr(get_app(),'dashtools_gui_cwd')).resolve())
-
 def create_box():
     return html.Div([
         dmc.Text('App Settings'),
@@ -128,7 +126,7 @@ def create_box():
                     id='app-location-input-createpage',
                     style={"width": '360px', 'margin-right': '10px'},
                     placeholder='App Path; eg. /Users/MyApp',
-                    value=_get_cwd()),
+                    value=str(os.getcwd())),
                 html.Div(
                     dmc.Tooltip(
                         id='app-settings-location-status',
